package com.emato.ich.fragment;

import android.os.Bundle;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.emato.ich.utils.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;

import androidx.annotation.NonNull;
import androidx.fragment.app.Fragment;

import com.emato.ich.MainActivity;
import com.emato.ich.R;
import com.emato.ich.contant.SystemConfigConstant;
import com.emato.ich.databinding.FragmentMainBinding;
import com.emato.ich.utils.ButtonUtils;
import com.emato.ich.utils.LoggingUtils;
import com.emato.ich.utils.NavUtils;
import com.emato.ich.utils.StringUtils;

import org.jetbrains.annotations.NotNull;

/**
 * 主页
 */
public class MainFragment extends Fragment {

    private static final String TAG = MainFragment.class.getName();
    private FragmentMainBinding binding;
    private long start;

    @Override
    public View onCreateView(
            @NotNull LayoutInflater inflater, ViewGroup container,
            Bundle savedInstanceState
    ) {
        start = System.currentTimeMillis();
        binding = FragmentMainBinding.inflate(inflater, container, false);
        return binding.getRoot();

    }

    public void onViewCreated(@NonNull View view, Bundle savedInstanceState) {
        long end = System.currentTimeMillis();
        Log.i(TAG, TAG + "页面渲染速度为" + (end - start) + "ms。");
        super.onViewCreated(view, savedInstanceState);
        MainActivity activity = (MainActivity) getActivity();
        String url = activity.getConfigMap().get(SystemConfigConstant.cabinet_take_object_qrcode_url);

        if (getActivity() != null && activity.getConfigMap().size() > 0 && !StringUtils.isNullOrEmpty(url)) {

            try {
                ImageView imageView = view.findViewById(R.id.fast_take_send);
                Glide.with(view).load(url)
                        .skipMemoryCache(true)//跳过内存缓存
                        .diskCacheStrategy(DiskCacheStrategy.NONE)//不缓冲disk硬盘中
                        .into(imageView);
            } catch (Exception e) {
                Log.e(TAG, "onResponse: Glide设置图片异常! ", e);
                LoggingUtils.sendErrorLog("业务异常: Glide请求微信公众号图片异常! ", e);
            }

        }
        Bundle bundle = new Bundle();
        // 我要寄快递页面跳转
        binding.sendBtn.setOnClickListener(view12 -> {
            if (ButtonUtils.isFastClick()) {
                return;
            }


            bundle.putString("pageType","expressDelivery");
            activity.getBundleMap().put(MainFragment.class.getName(), bundle);
            NavUtils.navigate(this, R.id.action_mainFragment_to_chooseCabinetFragment);
        });
        // 取件页面跳转 德合隐藏
//        binding.takeBtn.setOnClickListener(view1 -> {
//            if (ButtonUtils.isFastClick()) {
//                return;
//            }
//            NavUtils.navigate(this, R.id.action_mainFragment_to_takeFragment);
//        });
        // 派件员页面跳转
        binding.delivererBtn.setOnClickListener(view1 -> {
            if (ButtonUtils.isFastClick()) {
                return;
            }
            bundle.putString("pageType","collectMaterials");
            activity.getBundleMap().put(MainFragment.class.getName(), bundle);
            NavUtils.navigate(this, R.id.action_mainFragment_to_courier_fragment);
        });
    }

    @Override
    public void onDestroyView() {
        super.onDestroyView();
        binding = null;
        Log.i(TAG, TAG + "被销毁。。。");
    }

}